"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.query.v1beta1.pagination_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import tendermint.p2p.types_pb2
import tendermint.types.block_pb2
import tendermint.types.types_pb2

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GetValidatorSetByHeightRequest(google.protobuf.message.Message):
    """GetValidatorSetByHeightRequest is the request type for the Query/GetValidatorSetByHeight RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEIGHT_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    height: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an pagination for the request."""
    def __init__(
        self,
        *,
        height: builtins.int = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "pagination", b"pagination"]) -> None: ...

global___GetValidatorSetByHeightRequest = GetValidatorSetByHeightRequest

@typing_extensions.final
class GetValidatorSetByHeightResponse(google.protobuf.message.Message):
    """GetValidatorSetByHeightResponse is the response type for the Query/GetValidatorSetByHeight RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOCK_HEIGHT_FIELD_NUMBER: builtins.int
    VALIDATORS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    block_height: builtins.int
    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Validator]: ...
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines an pagination for the response."""
    def __init__(
        self,
        *,
        block_height: builtins.int = ...,
        validators: collections.abc.Iterable[global___Validator] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_height", b"block_height", "pagination", b"pagination", "validators", b"validators"]) -> None: ...

global___GetValidatorSetByHeightResponse = GetValidatorSetByHeightResponse

@typing_extensions.final
class GetLatestValidatorSetRequest(google.protobuf.message.Message):
    """GetLatestValidatorSetRequest is the request type for the Query/GetValidatorSetByHeight RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an pagination for the request."""
    def __init__(
        self,
        *,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> None: ...

global___GetLatestValidatorSetRequest = GetLatestValidatorSetRequest

@typing_extensions.final
class GetLatestValidatorSetResponse(google.protobuf.message.Message):
    """GetLatestValidatorSetResponse is the response type for the Query/GetValidatorSetByHeight RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOCK_HEIGHT_FIELD_NUMBER: builtins.int
    VALIDATORS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    block_height: builtins.int
    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Validator]: ...
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines an pagination for the response."""
    def __init__(
        self,
        *,
        block_height: builtins.int = ...,
        validators: collections.abc.Iterable[global___Validator] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_height", b"block_height", "pagination", b"pagination", "validators", b"validators"]) -> None: ...

global___GetLatestValidatorSetResponse = GetLatestValidatorSetResponse

@typing_extensions.final
class Validator(google.protobuf.message.Message):
    """Validator is the type for the validator-set."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    PUB_KEY_FIELD_NUMBER: builtins.int
    VOTING_POWER_FIELD_NUMBER: builtins.int
    PROPOSER_PRIORITY_FIELD_NUMBER: builtins.int
    address: builtins.str
    @property
    def pub_key(self) -> google.protobuf.any_pb2.Any: ...
    voting_power: builtins.int
    proposer_priority: builtins.int
    def __init__(
        self,
        *,
        address: builtins.str = ...,
        pub_key: google.protobuf.any_pb2.Any | None = ...,
        voting_power: builtins.int = ...,
        proposer_priority: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pub_key", b"pub_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "proposer_priority", b"proposer_priority", "pub_key", b"pub_key", "voting_power", b"voting_power"]) -> None: ...

global___Validator = Validator

@typing_extensions.final
class GetBlockByHeightRequest(google.protobuf.message.Message):
    """GetBlockByHeightRequest is the request type for the Query/GetBlockByHeight RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEIGHT_FIELD_NUMBER: builtins.int
    height: builtins.int
    def __init__(
        self,
        *,
        height: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height"]) -> None: ...

global___GetBlockByHeightRequest = GetBlockByHeightRequest

@typing_extensions.final
class GetBlockByHeightResponse(google.protobuf.message.Message):
    """GetBlockByHeightResponse is the response type for the Query/GetBlockByHeight RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOCK_ID_FIELD_NUMBER: builtins.int
    BLOCK_FIELD_NUMBER: builtins.int
    @property
    def block_id(self) -> tendermint.types.types_pb2.BlockID: ...
    @property
    def block(self) -> tendermint.types.block_pb2.Block: ...
    def __init__(
        self,
        *,
        block_id: tendermint.types.types_pb2.BlockID | None = ...,
        block: tendermint.types.block_pb2.Block | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["block", b"block", "block_id", b"block_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block", b"block", "block_id", b"block_id"]) -> None: ...

global___GetBlockByHeightResponse = GetBlockByHeightResponse

@typing_extensions.final
class GetLatestBlockRequest(google.protobuf.message.Message):
    """GetLatestBlockRequest is the request type for the Query/GetLatestBlock RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetLatestBlockRequest = GetLatestBlockRequest

@typing_extensions.final
class GetLatestBlockResponse(google.protobuf.message.Message):
    """GetLatestBlockResponse is the response type for the Query/GetLatestBlock RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOCK_ID_FIELD_NUMBER: builtins.int
    BLOCK_FIELD_NUMBER: builtins.int
    @property
    def block_id(self) -> tendermint.types.types_pb2.BlockID: ...
    @property
    def block(self) -> tendermint.types.block_pb2.Block: ...
    def __init__(
        self,
        *,
        block_id: tendermint.types.types_pb2.BlockID | None = ...,
        block: tendermint.types.block_pb2.Block | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["block", b"block", "block_id", b"block_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block", b"block", "block_id", b"block_id"]) -> None: ...

global___GetLatestBlockResponse = GetLatestBlockResponse

@typing_extensions.final
class GetSyncingRequest(google.protobuf.message.Message):
    """GetSyncingRequest is the request type for the Query/GetSyncing RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetSyncingRequest = GetSyncingRequest

@typing_extensions.final
class GetSyncingResponse(google.protobuf.message.Message):
    """GetSyncingResponse is the response type for the Query/GetSyncing RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SYNCING_FIELD_NUMBER: builtins.int
    syncing: builtins.bool
    def __init__(
        self,
        *,
        syncing: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["syncing", b"syncing"]) -> None: ...

global___GetSyncingResponse = GetSyncingResponse

@typing_extensions.final
class GetNodeInfoRequest(google.protobuf.message.Message):
    """GetNodeInfoRequest is the request type for the Query/GetNodeInfo RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetNodeInfoRequest = GetNodeInfoRequest

@typing_extensions.final
class GetNodeInfoResponse(google.protobuf.message.Message):
    """GetNodeInfoResponse is the request type for the Query/GetNodeInfo RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_NODE_INFO_FIELD_NUMBER: builtins.int
    APPLICATION_VERSION_FIELD_NUMBER: builtins.int
    @property
    def default_node_info(self) -> tendermint.p2p.types_pb2.DefaultNodeInfo: ...
    @property
    def application_version(self) -> global___VersionInfo: ...
    def __init__(
        self,
        *,
        default_node_info: tendermint.p2p.types_pb2.DefaultNodeInfo | None = ...,
        application_version: global___VersionInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["application_version", b"application_version", "default_node_info", b"default_node_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_version", b"application_version", "default_node_info", b"default_node_info"]) -> None: ...

global___GetNodeInfoResponse = GetNodeInfoResponse

@typing_extensions.final
class VersionInfo(google.protobuf.message.Message):
    """VersionInfo is the type for the GetNodeInfoResponse message."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    APP_NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    GIT_COMMIT_FIELD_NUMBER: builtins.int
    BUILD_TAGS_FIELD_NUMBER: builtins.int
    GO_VERSION_FIELD_NUMBER: builtins.int
    BUILD_DEPS_FIELD_NUMBER: builtins.int
    COSMOS_SDK_VERSION_FIELD_NUMBER: builtins.int
    name: builtins.str
    app_name: builtins.str
    version: builtins.str
    git_commit: builtins.str
    build_tags: builtins.str
    go_version: builtins.str
    @property
    def build_deps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Module]: ...
    cosmos_sdk_version: builtins.str
    """Since: cosmos-sdk 0.43"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        app_name: builtins.str = ...,
        version: builtins.str = ...,
        git_commit: builtins.str = ...,
        build_tags: builtins.str = ...,
        go_version: builtins.str = ...,
        build_deps: collections.abc.Iterable[global___Module] | None = ...,
        cosmos_sdk_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_name", b"app_name", "build_deps", b"build_deps", "build_tags", b"build_tags", "cosmos_sdk_version", b"cosmos_sdk_version", "git_commit", b"git_commit", "go_version", b"go_version", "name", b"name", "version", b"version"]) -> None: ...

global___VersionInfo = VersionInfo

@typing_extensions.final
class Module(google.protobuf.message.Message):
    """Module is the type for VersionInfo"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    SUM_FIELD_NUMBER: builtins.int
    path: builtins.str
    """module path"""
    version: builtins.str
    """module version"""
    sum: builtins.str
    """checksum"""
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        version: builtins.str = ...,
        sum: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path", "sum", b"sum", "version", b"version"]) -> None: ...

global___Module = Module



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/lockup/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from osmosis.lockup import lock_pb2 as osmosis_dot_lockup_dot_lock__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17osmosis/lockup/tx.proto\x12\x0eosmosis.lockup\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x19osmosis/lockup/lock.proto\"\xec\x01\n\rMsgLockTokens\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12^\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB1\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xea\xde\x1f\x12\x64uration,omitempty\xf2\xde\x1f\x0fyaml:\"duration\"\x12Z\n\x05\x63oins\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"#\n\x15MsgLockTokensResponse\x12\n\n\x02ID\x18\x01 \x01(\x04\"7\n\x14MsgBeginUnlockingAll\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\"K\n\x1cMsgBeginUnlockingAllResponse\x12+\n\x07unlocks\x18\x01 \x03(\x0b\x32\x1a.osmosis.lockup.PeriodLock\"\x9c\x01\n\x11MsgBeginUnlocking\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12\n\n\x02ID\x18\x02 \x01(\x04\x12Z\n\x05\x63oins\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\",\n\x19MsgBeginUnlockingResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\x9e\x01\n\x0fMsgExtendLockup\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12\n\n\x02ID\x18\x02 \x01(\x04\x12^\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB1\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xea\xde\x1f\x12\x64uration,omitempty\xf2\xde\x1f\x0fyaml:\"duration\"\"*\n\x17MsgExtendLockupResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\x99\x01\n\x0eMsgForceUnlock\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12\n\n\x02ID\x18\x02 \x01(\x04\x12Z\n\x05\x63oins\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\")\n\x16MsgForceUnlockResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32\xd3\x03\n\x03Msg\x12R\n\nLockTokens\x12\x1d.osmosis.lockup.MsgLockTokens\x1a%.osmosis.lockup.MsgLockTokensResponse\x12g\n\x11\x42\x65ginUnlockingAll\x12$.osmosis.lockup.MsgBeginUnlockingAll\x1a,.osmosis.lockup.MsgBeginUnlockingAllResponse\x12^\n\x0e\x42\x65ginUnlocking\x12!.osmosis.lockup.MsgBeginUnlocking\x1a).osmosis.lockup.MsgBeginUnlockingResponse\x12X\n\x0c\x45xtendLockup\x12\x1f.osmosis.lockup.MsgExtendLockup\x1a\'.osmosis.lockup.MsgExtendLockupResponse\x12U\n\x0b\x46orceUnlock\x12\x1e.osmosis.lockup.MsgForceUnlock\x1a&.osmosis.lockup.MsgForceUnlockResponseB4Z2github.com/osmosis-labs/osmosis/v14/x/lockup/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.lockup.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/osmosis-labs/osmosis/v14/x/lockup/types'
  _MSGLOCKTOKENS.fields_by_name['owner']._options = None
  _MSGLOCKTOKENS.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _MSGLOCKTOKENS.fields_by_name['duration']._options = None
  _MSGLOCKTOKENS.fields_by_name['duration']._serialized_options = b'\310\336\037\000\230\337\037\001\352\336\037\022duration,omitempty\362\336\037\017yaml:\"duration\"'
  _MSGLOCKTOKENS.fields_by_name['coins']._options = None
  _MSGLOCKTOKENS.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGBEGINUNLOCKINGALL.fields_by_name['owner']._options = None
  _MSGBEGINUNLOCKINGALL.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _MSGBEGINUNLOCKING.fields_by_name['owner']._options = None
  _MSGBEGINUNLOCKING.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _MSGBEGINUNLOCKING.fields_by_name['coins']._options = None
  _MSGBEGINUNLOCKING.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGEXTENDLOCKUP.fields_by_name['owner']._options = None
  _MSGEXTENDLOCKUP.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _MSGEXTENDLOCKUP.fields_by_name['duration']._options = None
  _MSGEXTENDLOCKUP.fields_by_name['duration']._serialized_options = b'\310\336\037\000\230\337\037\001\352\336\037\022duration,omitempty\362\336\037\017yaml:\"duration\"'
  _MSGFORCEUNLOCK.fields_by_name['owner']._options = None
  _MSGFORCEUNLOCK.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _MSGFORCEUNLOCK.fields_by_name['coins']._options = None
  _MSGFORCEUNLOCK.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGLOCKTOKENS._serialized_start=157
  _MSGLOCKTOKENS._serialized_end=393
  _MSGLOCKTOKENSRESPONSE._serialized_start=395
  _MSGLOCKTOKENSRESPONSE._serialized_end=430
  _MSGBEGINUNLOCKINGALL._serialized_start=432
  _MSGBEGINUNLOCKINGALL._serialized_end=487
  _MSGBEGINUNLOCKINGALLRESPONSE._serialized_start=489
  _MSGBEGINUNLOCKINGALLRESPONSE._serialized_end=564
  _MSGBEGINUNLOCKING._serialized_start=567
  _MSGBEGINUNLOCKING._serialized_end=723
  _MSGBEGINUNLOCKINGRESPONSE._serialized_start=725
  _MSGBEGINUNLOCKINGRESPONSE._serialized_end=769
  _MSGEXTENDLOCKUP._serialized_start=772
  _MSGEXTENDLOCKUP._serialized_end=930
  _MSGEXTENDLOCKUPRESPONSE._serialized_start=932
  _MSGEXTENDLOCKUPRESPONSE._serialized_end=974
  _MSGFORCEUNLOCK._serialized_start=977
  _MSGFORCEUNLOCK._serialized_end=1130
  _MSGFORCEUNLOCKRESPONSE._serialized_start=1132
  _MSGFORCEUNLOCKRESPONSE._serialized_end=1173
  _MSG._serialized_start=1176
  _MSG._serialized_end=1643
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/incentives/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google_apis.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from osmosis.incentives import gauge_pb2 as osmosis_dot_incentives_dot_gauge__pb2
from osmosis.lockup import lock_pb2 as osmosis_dot_lockup_dot_lock__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eosmosis/incentives/query.proto\x12\x12osmosis.incentives\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1eosmosis/incentives/gauge.proto\x1a\x19osmosis/lockup/lock.proto\" \n\x1eModuleToDistributeCoinsRequest\"}\n\x1fModuleToDistributeCoinsResponse\x12Z\n\x05\x63oins\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\x1e\n\x10GaugeByIDRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"=\n\x11GaugeByIDResponse\x12(\n\x05gauge\x18\x01 \x01(\x0b\x32\x19.osmosis.incentives.Gauge\"K\n\rGaugesRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"|\n\x0eGaugesResponse\x12-\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x19.osmosis.incentives.GaugeB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"Q\n\x13\x41\x63tiveGaugesRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x82\x01\n\x14\x41\x63tiveGaugesResponse\x12-\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x19.osmosis.incentives.GaugeB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"h\n\x1b\x41\x63tiveGaugesPerDenomRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8a\x01\n\x1c\x41\x63tiveGaugesPerDenomResponse\x12-\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x19.osmosis.incentives.GaugeB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"S\n\x15UpcomingGaugesRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x84\x01\n\x16UpcomingGaugesResponse\x12-\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x19.osmosis.incentives.GaugeB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"j\n\x1dUpcomingGaugesPerDenomRequest\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x97\x01\n\x1eUpcomingGaugesPerDenomResponse\x12\x38\n\x0fupcoming_gauges\x18\x01 \x03(\x0b\x32\x19.osmosis.incentives.GaugeB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"Y\n\x11RewardsEstRequest\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12\x10\n\x08lock_ids\x18\x02 \x03(\x04\x12\x11\n\tend_epoch\x18\x03 \x01(\x03\"p\n\x12RewardsEstResponse\x12Z\n\x05\x63oins\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\x1f\n\x1dQueryLockableDurationsRequest\"~\n\x1eQueryLockableDurationsResponse\x12\\\n\x12lockable_durations\x18\x01 \x03(\x0b\x32\x19.google.protobuf.DurationB%\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xf2\xde\x1f\x19yaml:\"lockable_durations\"2\xd6\x0b\n\x05Query\x12\xc2\x01\n\x17ModuleToDistributeCoins\x12\x32.osmosis.incentives.ModuleToDistributeCoinsRequest\x1a\x33.osmosis.incentives.ModuleToDistributeCoinsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/osmosis/incentives/v1beta1/module_to_distribute_coins\x12\x8e\x01\n\tGaugeByID\x12$.osmosis.incentives.GaugeByIDRequest\x1a%.osmosis.incentives.GaugeByIDResponse\"4\x82\xd3\xe4\x93\x02.\x12,/osmosis/incentives/v1beta1/gauge_by_id/{id}\x12{\n\x06Gauges\x12!.osmosis.incentives.GaugesRequest\x1a\".osmosis.incentives.GaugesResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/osmosis/incentives/v1beta1/gauges\x12\x94\x01\n\x0c\x41\x63tiveGauges\x12\'.osmosis.incentives.ActiveGaugesRequest\x1a(.osmosis.incentives.ActiveGaugesResponse\"1\x82\xd3\xe4\x93\x02+\x12)/osmosis/incentives/v1beta1/active_gauges\x12\xb6\x01\n\x14\x41\x63tiveGaugesPerDenom\x12/.osmosis.incentives.ActiveGaugesPerDenomRequest\x1a\x30.osmosis.incentives.ActiveGaugesPerDenomResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/osmosis/incentives/v1beta1/active_gauges_per_denom\x12\x9c\x01\n\x0eUpcomingGauges\x12).osmosis.incentives.UpcomingGaugesRequest\x1a*.osmosis.incentives.UpcomingGaugesResponse\"3\x82\xd3\xe4\x93\x02-\x12+/osmosis/incentives/v1beta1/upcoming_gauges\x12\xbe\x01\n\x16UpcomingGaugesPerDenom\x12\x31.osmosis.incentives.UpcomingGaugesPerDenomRequest\x1a\x32.osmosis.incentives.UpcomingGaugesPerDenomResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/osmosis/incentives/v1beta1/upcoming_gauges_per_denom\x12\x94\x01\n\nRewardsEst\x12%.osmosis.incentives.RewardsEstRequest\x1a&.osmosis.incentives.RewardsEstResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//osmosis/incentives/v1beta1/rewards_est/{owner}\x12\xb2\x01\n\x11LockableDurations\x12\x31.osmosis.incentives.QueryLockableDurationsRequest\x1a\x32.osmosis.incentives.QueryLockableDurationsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./osmosis/incentives/v1beta1/lockable_durationsB8Z6github.com/osmosis-labs/osmosis/v14/x/incentives/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.incentives.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z6github.com/osmosis-labs/osmosis/v14/x/incentives/types'
  _MODULETODISTRIBUTECOINSRESPONSE.fields_by_name['coins']._options = None
  _MODULETODISTRIBUTECOINSRESPONSE.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _GAUGESRESPONSE.fields_by_name['data']._options = None
  _GAUGESRESPONSE.fields_by_name['data']._serialized_options = b'\310\336\037\000'
  _ACTIVEGAUGESRESPONSE.fields_by_name['data']._options = None
  _ACTIVEGAUGESRESPONSE.fields_by_name['data']._serialized_options = b'\310\336\037\000'
  _ACTIVEGAUGESPERDENOMRESPONSE.fields_by_name['data']._options = None
  _ACTIVEGAUGESPERDENOMRESPONSE.fields_by_name['data']._serialized_options = b'\310\336\037\000'
  _UPCOMINGGAUGESRESPONSE.fields_by_name['data']._options = None
  _UPCOMINGGAUGESRESPONSE.fields_by_name['data']._serialized_options = b'\310\336\037\000'
  _UPCOMINGGAUGESPERDENOMRESPONSE.fields_by_name['upcoming_gauges']._options = None
  _UPCOMINGGAUGESPERDENOMRESPONSE.fields_by_name['upcoming_gauges']._serialized_options = b'\310\336\037\000'
  _REWARDSESTREQUEST.fields_by_name['owner']._options = None
  _REWARDSESTREQUEST.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _REWARDSESTRESPONSE.fields_by_name['coins']._options = None
  _REWARDSESTRESPONSE.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _QUERYLOCKABLEDURATIONSRESPONSE.fields_by_name['lockable_durations']._options = None
  _QUERYLOCKABLEDURATIONSRESPONSE.fields_by_name['lockable_durations']._serialized_options = b'\310\336\037\000\230\337\037\001\362\336\037\031yaml:\"lockable_durations\"'
  _QUERY.methods_by_name['ModuleToDistributeCoins']._options = None
  _QUERY.methods_by_name['ModuleToDistributeCoins']._serialized_options = b'\202\323\344\223\0028\0226/osmosis/incentives/v1beta1/module_to_distribute_coins'
  _QUERY.methods_by_name['GaugeByID']._options = None
  _QUERY.methods_by_name['GaugeByID']._serialized_options = b'\202\323\344\223\002.\022,/osmosis/incentives/v1beta1/gauge_by_id/{id}'
  _QUERY.methods_by_name['Gauges']._options = None
  _QUERY.methods_by_name['Gauges']._serialized_options = b'\202\323\344\223\002$\022\"/osmosis/incentives/v1beta1/gauges'
  _QUERY.methods_by_name['ActiveGauges']._options = None
  _QUERY.methods_by_name['ActiveGauges']._serialized_options = b'\202\323\344\223\002+\022)/osmosis/incentives/v1beta1/active_gauges'
  _QUERY.methods_by_name['ActiveGaugesPerDenom']._options = None
  _QUERY.methods_by_name['ActiveGaugesPerDenom']._serialized_options = b'\202\323\344\223\0025\0223/osmosis/incentives/v1beta1/active_gauges_per_denom'
  _QUERY.methods_by_name['UpcomingGauges']._options = None
  _QUERY.methods_by_name['UpcomingGauges']._serialized_options = b'\202\323\344\223\002-\022+/osmosis/incentives/v1beta1/upcoming_gauges'
  _QUERY.methods_by_name['UpcomingGaugesPerDenom']._options = None
  _QUERY.methods_by_name['UpcomingGaugesPerDenom']._serialized_options = b'\202\323\344\223\0027\0225/osmosis/incentives/v1beta1/upcoming_gauges_per_denom'
  _QUERY.methods_by_name['RewardsEst']._options = None
  _QUERY.methods_by_name['RewardsEst']._serialized_options = b'\202\323\344\223\0021\022//osmosis/incentives/v1beta1/rewards_est/{owner}'
  _QUERY.methods_by_name['LockableDurations']._options = None
  _QUERY.methods_by_name['LockableDurations']._serialized_options = b'\202\323\344\223\0020\022./osmosis/incentives/v1beta1/lockable_durations'
  _MODULETODISTRIBUTECOINSREQUEST._serialized_start=273
  _MODULETODISTRIBUTECOINSREQUEST._serialized_end=305
  _MODULETODISTRIBUTECOINSRESPONSE._serialized_start=307
  _MODULETODISTRIBUTECOINSRESPONSE._serialized_end=432
  _GAUGEBYIDREQUEST._serialized_start=434
  _GAUGEBYIDREQUEST._serialized_end=464
  _GAUGEBYIDRESPONSE._serialized_start=466
  _GAUGEBYIDRESPONSE._serialized_end=527
  _GAUGESREQUEST._serialized_start=529
  _GAUGESREQUEST._serialized_end=604
  _GAUGESRESPONSE._serialized_start=606
  _GAUGESRESPONSE._serialized_end=730
  _ACTIVEGAUGESREQUEST._serialized_start=732
  _ACTIVEGAUGESREQUEST._serialized_end=813
  _ACTIVEGAUGESRESPONSE._serialized_start=816
  _ACTIVEGAUGESRESPONSE._serialized_end=946
  _ACTIVEGAUGESPERDENOMREQUEST._serialized_start=948
  _ACTIVEGAUGESPERDENOMREQUEST._serialized_end=1052
  _ACTIVEGAUGESPERDENOMRESPONSE._serialized_start=1055
  _ACTIVEGAUGESPERDENOMRESPONSE._serialized_end=1193
  _UPCOMINGGAUGESREQUEST._serialized_start=1195
  _UPCOMINGGAUGESREQUEST._serialized_end=1278
  _UPCOMINGGAUGESRESPONSE._serialized_start=1281
  _UPCOMINGGAUGESRESPONSE._serialized_end=1413
  _UPCOMINGGAUGESPERDENOMREQUEST._serialized_start=1415
  _UPCOMINGGAUGESPERDENOMREQUEST._serialized_end=1521
  _UPCOMINGGAUGESPERDENOMRESPONSE._serialized_start=1524
  _UPCOMINGGAUGESPERDENOMRESPONSE._serialized_end=1675
  _REWARDSESTREQUEST._serialized_start=1677
  _REWARDSESTREQUEST._serialized_end=1766
  _REWARDSESTRESPONSE._serialized_start=1768
  _REWARDSESTRESPONSE._serialized_end=1880
  _QUERYLOCKABLEDURATIONSREQUEST._serialized_start=1882
  _QUERYLOCKABLEDURATIONSREQUEST._serialized_end=1913
  _QUERYLOCKABLEDURATIONSRESPONSE._serialized_start=1915
  _QUERYLOCKABLEDURATIONSRESPONSE._serialized_end=2041
  _QUERY._serialized_start=2044
  _QUERY._serialized_end=3538
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Since: cosmos-sdk 0.43"""
import builtins
import collections.abc
import cosmos.feegrant.v1beta1.feegrant_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState contains a set of fee allowances, persisted from the store"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWANCES_FIELD_NUMBER: builtins.int
    @property
    def allowances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.feegrant.v1beta1.feegrant_pb2.Grant]: ...
    def __init__(
        self,
        *,
        allowances: collections.abc.Iterable[cosmos.feegrant.v1beta1.feegrant_pb2.Grant] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowances", b"allowances"]) -> None: ...

global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.query.v1beta1.pagination_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QueryEvidenceRequest(google.protobuf.message.Message):
    """QueryEvidenceRequest is the request type for the Query/Evidence RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVIDENCE_HASH_FIELD_NUMBER: builtins.int
    evidence_hash: builtins.bytes
    """evidence_hash defines the hash of the requested evidence."""
    def __init__(
        self,
        *,
        evidence_hash: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["evidence_hash", b"evidence_hash"]) -> None: ...

global___QueryEvidenceRequest = QueryEvidenceRequest

@typing_extensions.final
class QueryEvidenceResponse(google.protobuf.message.Message):
    """QueryEvidenceResponse is the response type for the Query/Evidence RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVIDENCE_FIELD_NUMBER: builtins.int
    @property
    def evidence(self) -> google.protobuf.any_pb2.Any:
        """evidence returns the requested evidence."""
    def __init__(
        self,
        *,
        evidence: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["evidence", b"evidence"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["evidence", b"evidence"]) -> None: ...

global___QueryEvidenceResponse = QueryEvidenceResponse

@typing_extensions.final
class QueryAllEvidenceRequest(google.protobuf.message.Message):
    """QueryEvidenceRequest is the request type for the Query/AllEvidence RPC
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
    def __init__(
        self,
        *,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> None: ...

global___QueryAllEvidenceRequest = QueryAllEvidenceRequest

@typing_extensions.final
class QueryAllEvidenceResponse(google.protobuf.message.Message):
    """QueryAllEvidenceResponse is the response type for the Query/AllEvidence RPC
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVIDENCE_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def evidence(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """evidence returns all evidences."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
    def __init__(
        self,
        *,
        evidence: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["evidence", b"evidence", "pagination", b"pagination"]) -> None: ...

global___QueryAllEvidenceResponse = QueryAllEvidenceResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.bank.v1beta1.tx_pb2
import grpc

class MsgStub:
    """Msg defines the bank Msg service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    Send: grpc.UnaryUnaryMultiCallable[
        cosmos.bank.v1beta1.tx_pb2.MsgSend,
        cosmos.bank.v1beta1.tx_pb2.MsgSendResponse,
    ]
    """Send defines a method for sending coins from one account to another
    account.
    """
    MultiSend: grpc.UnaryUnaryMultiCallable[
        cosmos.bank.v1beta1.tx_pb2.MsgMultiSend,
        cosmos.bank.v1beta1.tx_pb2.MsgMultiSendResponse,
    ]
    """MultiSend defines a method for sending coins from a single account to
    multiple accounts. It can be seen as a single message representation of
    multiple individual MsgSend messages.
    """

class MsgServicer(metaclass=abc.ABCMeta):
    """Msg defines the bank Msg service."""

    @abc.abstractmethod
    def Send(
        self,
        request: cosmos.bank.v1beta1.tx_pb2.MsgSend,
        context: grpc.ServicerContext,
    ) -> cosmos.bank.v1beta1.tx_pb2.MsgSendResponse:
        """Send defines a method for sending coins from one account to another
        account.
        """
    @abc.abstractmethod
    def MultiSend(
        self,
        request: cosmos.bank.v1beta1.tx_pb2.MsgMultiSend,
        context: grpc.ServicerContext,
    ) -> cosmos.bank.v1beta1.tx_pb2.MsgMultiSendResponse:
        """MultiSend defines a method for sending coins from a single account to
        multiple accounts. It can be seen as a single message representation of
        multiple individual MsgSend messages.
        """

def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/gamm/pool-models/balancer/balancerPool.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4osmosis/gamm/pool-models/balancer/balancerPool.proto\x12\x14osmosis.gamm.v1beta1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1e\x63osmos/auth/v1beta1/auth.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x8f\x03\n\x18SmoothWeightChangeParams\x12M\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1d\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x11yaml:\"start_time\"\x12^\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB1\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xea\xde\x1f\x12\x64uration,omitempty\xf2\xde\x1f\x0fyaml:\"duration\"\x12\x62\n\x14initial_pool_weights\x18\x03 \x03(\x0b\x32\x1f.osmosis.gamm.v1beta1.PoolAssetB#\xf2\xde\x1f\x1byaml:\"initial_pool_weights\"\xc8\xde\x1f\x00\x12`\n\x13target_pool_weights\x18\x04 \x03(\x0b\x32\x1f.osmosis.gamm.v1beta1.PoolAssetB\"\xf2\xde\x1f\x1ayaml:\"target_pool_weights\"\xc8\xde\x1f\x00\"\xb7\x02\n\nPoolParams\x12S\n\x08swap_fee\x18\x01 \x01(\tBA\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x0fyaml:\"swap_fee\"\xc8\xde\x1f\x00\x12S\n\x08\x65xit_fee\x18\x02 \x01(\tBA\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xf2\xde\x1f\x0fyaml:\"exit_fee\"\xc8\xde\x1f\x00\x12\x7f\n\x1bsmooth_weight_change_params\x18\x03 \x01(\x0b\x32..osmosis.gamm.v1beta1.SmoothWeightChangeParamsB*\xf2\xde\x1f\"yaml:\"smooth_weight_change_params\"\xc8\xde\x1f\x01\"\x9c\x01\n\tPoolAsset\x12>\n\x05token\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x14\xf2\xde\x1f\x0cyaml:\"token\"\xc8\xde\x1f\x00\x12O\n\x06weight\x18\x02 \x01(\tB?\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\ryaml:\"weight\"\xc8\xde\x1f\x00\"\xe2\x03\n\x04Pool\x12#\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"address\"\x12\n\n\x02id\x18\x02 \x01(\x04\x12Z\n\x0bpool_params\x18\x03 \x01(\x0b\x32 .osmosis.gamm.v1beta1.PoolParamsB#\xf2\xde\x1f\x1byaml:\"balancer_pool_params\"\xc8\xde\x1f\x00\x12=\n\x14\x66uture_pool_governor\x18\x04 \x01(\tB\x1f\xf2\xde\x1f\x1byaml:\"future_pool_governor\"\x12L\n\x0ctotal_shares\x18\x05 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x1b\xf2\xde\x1f\x13yaml:\"total_shares\"\xc8\xde\x1f\x00\x12P\n\x0bpool_assets\x18\x06 \x03(\x0b\x32\x1f.osmosis.gamm.v1beta1.PoolAssetB\x1a\xf2\xde\x1f\x12yaml:\"pool_assets\"\xc8\xde\x1f\x00\x12[\n\x0ctotal_weight\x18\x07 \x01(\tBE\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x13yaml:\"total_weight\"\xc8\xde\x1f\x00:\x11\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xd2\xb4-\x05PoolIBAZ?github.com/osmosis-labs/osmosis/v14/x/gamm/pool-models/balancerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.gamm.pool_models.balancer.balancerPool_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z?github.com/osmosis-labs/osmosis/v14/x/gamm/pool-models/balancer'
  _SMOOTHWEIGHTCHANGEPARAMS.fields_by_name['start_time']._options = None
  _SMOOTHWEIGHTCHANGEPARAMS.fields_by_name['start_time']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\021yaml:\"start_time\"'
  _SMOOTHWEIGHTCHANGEPARAMS.fields_by_name['duration']._options = None
  _SMOOTHWEIGHTCHANGEPARAMS.fields_by_name['duration']._serialized_options = b'\310\336\037\000\230\337\037\001\352\336\037\022duration,omitempty\362\336\037\017yaml:\"duration\"'
  _SMOOTHWEIGHTCHANGEPARAMS.fields_by_name['initial_pool_weights']._options = None
  _SMOOTHWEIGHTCHANGEPARAMS.fields_by_name['initial_pool_weights']._serialized_options = b'\362\336\037\033yaml:\"initial_pool_weights\"\310\336\037\000'
  _SMOOTHWEIGHTCHANGEPARAMS.fields_by_name['target_pool_weights']._options = None
  _SMOOTHWEIGHTCHANGEPARAMS.fields_by_name['target_pool_weights']._serialized_options = b'\362\336\037\032yaml:\"target_pool_weights\"\310\336\037\000'
  _POOLPARAMS.fields_by_name['swap_fee']._options = None
  _POOLPARAMS.fields_by_name['swap_fee']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\017yaml:\"swap_fee\"\310\336\037\000'
  _POOLPARAMS.fields_by_name['exit_fee']._options = None
  _POOLPARAMS.fields_by_name['exit_fee']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\362\336\037\017yaml:\"exit_fee\"\310\336\037\000'
  _POOLPARAMS.fields_by_name['smooth_weight_change_params']._options = None
  _POOLPARAMS.fields_by_name['smooth_weight_change_params']._serialized_options = b'\362\336\037\"yaml:\"smooth_weight_change_params\"\310\336\037\001'
  _POOLASSET.fields_by_name['token']._options = None
  _POOLASSET.fields_by_name['token']._serialized_options = b'\362\336\037\014yaml:\"token\"\310\336\037\000'
  _POOLASSET.fields_by_name['weight']._options = None
  _POOLASSET.fields_by_name['weight']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\ryaml:\"weight\"\310\336\037\000'
  _POOL.fields_by_name['address']._options = None
  _POOL.fields_by_name['address']._serialized_options = b'\362\336\037\016yaml:\"address\"'
  _POOL.fields_by_name['pool_params']._options = None
  _POOL.fields_by_name['pool_params']._serialized_options = b'\362\336\037\033yaml:\"balancer_pool_params\"\310\336\037\000'
  _POOL.fields_by_name['future_pool_governor']._options = None
  _POOL.fields_by_name['future_pool_governor']._serialized_options = b'\362\336\037\033yaml:\"future_pool_governor\"'
  _POOL.fields_by_name['total_shares']._options = None
  _POOL.fields_by_name['total_shares']._serialized_options = b'\362\336\037\023yaml:\"total_shares\"\310\336\037\000'
  _POOL.fields_by_name['pool_assets']._options = None
  _POOL.fields_by_name['pool_assets']._serialized_options = b'\362\336\037\022yaml:\"pool_assets\"\310\336\037\000'
  _POOL.fields_by_name['total_weight']._options = None
  _POOL.fields_by_name['total_weight']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\023yaml:\"total_weight\"\310\336\037\000'
  _POOL._options = None
  _POOL._serialized_options = b'\210\240\037\000\230\240\037\000\322\264-\005PoolI'
  _SMOOTHWEIGHTCHANGEPARAMS._serialized_start=257
  _SMOOTHWEIGHTCHANGEPARAMS._serialized_end=656
  _POOLPARAMS._serialized_start=659
  _POOLPARAMS._serialized_end=970
  _POOLASSET._serialized_start=973
  _POOLASSET._serialized_end=1129
  _POOL._serialized_start=1132
  _POOL._serialized_end=1614
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CommitInfo(google.protobuf.message.Message):
    """CommitInfo defines commit information used by the multi-store when committing
    a version/height.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    STORE_INFOS_FIELD_NUMBER: builtins.int
    version: builtins.int
    @property
    def store_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StoreInfo]: ...
    def __init__(
        self,
        *,
        version: builtins.int = ...,
        store_infos: collections.abc.Iterable[global___StoreInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["store_infos", b"store_infos", "version", b"version"]) -> None: ...

global___CommitInfo = CommitInfo

@typing_extensions.final
class StoreInfo(google.protobuf.message.Message):
    """StoreInfo defines store-specific commit information. It contains a reference
    between a store name and the commit ID.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    COMMIT_ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def commit_id(self) -> global___CommitID: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        commit_id: global___CommitID | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["commit_id", b"commit_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["commit_id", b"commit_id", "name", b"name"]) -> None: ...

global___StoreInfo = StoreInfo

@typing_extensions.final
class CommitID(google.protobuf.message.Message):
    """CommitID defines the committment information when a specific store is
    committed.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    version: builtins.int
    hash: builtins.bytes
    def __init__(
        self,
        *,
        version: builtins.int = ...,
        hash: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hash", b"hash", "version", b"version"]) -> None: ...

global___CommitID = CommitID



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import osmosis.twap.v1beta1.genesis_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ArithmeticTwapRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    BASE_ASSET_FIELD_NUMBER: builtins.int
    QUOTE_ASSET_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    base_asset: builtins.str
    quote_asset: builtins.str
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        base_asset: builtins.str = ...,
        quote_asset: builtins.str = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_asset", b"base_asset", "end_time", b"end_time", "pool_id", b"pool_id", "quote_asset", b"quote_asset", "start_time", b"start_time"]) -> None: ...

global___ArithmeticTwapRequest = ArithmeticTwapRequest

@typing_extensions.final
class ArithmeticTwapResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARITHMETIC_TWAP_FIELD_NUMBER: builtins.int
    arithmetic_twap: builtins.str
    def __init__(
        self,
        *,
        arithmetic_twap: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arithmetic_twap", b"arithmetic_twap"]) -> None: ...

global___ArithmeticTwapResponse = ArithmeticTwapResponse

@typing_extensions.final
class ArithmeticTwapToNowRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    BASE_ASSET_FIELD_NUMBER: builtins.int
    QUOTE_ASSET_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    base_asset: builtins.str
    quote_asset: builtins.str
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        base_asset: builtins.str = ...,
        quote_asset: builtins.str = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_asset", b"base_asset", "pool_id", b"pool_id", "quote_asset", b"quote_asset", "start_time", b"start_time"]) -> None: ...

global___ArithmeticTwapToNowRequest = ArithmeticTwapToNowRequest

@typing_extensions.final
class ArithmeticTwapToNowResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARITHMETIC_TWAP_FIELD_NUMBER: builtins.int
    arithmetic_twap: builtins.str
    def __init__(
        self,
        *,
        arithmetic_twap: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arithmetic_twap", b"arithmetic_twap"]) -> None: ...

global___ArithmeticTwapToNowResponse = ArithmeticTwapToNowResponse

@typing_extensions.final
class GeometricTwapRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    BASE_ASSET_FIELD_NUMBER: builtins.int
    QUOTE_ASSET_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    base_asset: builtins.str
    quote_asset: builtins.str
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        base_asset: builtins.str = ...,
        quote_asset: builtins.str = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_asset", b"base_asset", "end_time", b"end_time", "pool_id", b"pool_id", "quote_asset", b"quote_asset", "start_time", b"start_time"]) -> None: ...

global___GeometricTwapRequest = GeometricTwapRequest

@typing_extensions.final
class GeometricTwapResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GEOMETRIC_TWAP_FIELD_NUMBER: builtins.int
    geometric_twap: builtins.str
    def __init__(
        self,
        *,
        geometric_twap: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["geometric_twap", b"geometric_twap"]) -> None: ...

global___GeometricTwapResponse = GeometricTwapResponse

@typing_extensions.final
class GeometricTwapToNowRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    BASE_ASSET_FIELD_NUMBER: builtins.int
    QUOTE_ASSET_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    base_asset: builtins.str
    quote_asset: builtins.str
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        base_asset: builtins.str = ...,
        quote_asset: builtins.str = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_asset", b"base_asset", "pool_id", b"pool_id", "quote_asset", b"quote_asset", "start_time", b"start_time"]) -> None: ...

global___GeometricTwapToNowRequest = GeometricTwapToNowRequest

@typing_extensions.final
class GeometricTwapToNowResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GEOMETRIC_TWAP_FIELD_NUMBER: builtins.int
    geometric_twap: builtins.str
    def __init__(
        self,
        *,
        geometric_twap: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["geometric_twap", b"geometric_twap"]) -> None: ...

global___GeometricTwapToNowResponse = GeometricTwapToNowResponse

@typing_extensions.final
class ParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ParamsRequest = ParamsRequest

@typing_extensions.final
class ParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> osmosis.twap.v1beta1.genesis_pb2.Params: ...
    def __init__(
        self,
        *,
        params: osmosis.twap.v1beta1.genesis_pb2.Params | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params", b"params"]) -> None: ...

global___ParamsResponse = ParamsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Proof(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOTAL_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    LEAF_HASH_FIELD_NUMBER: builtins.int
    AUNTS_FIELD_NUMBER: builtins.int
    total: builtins.int
    index: builtins.int
    leaf_hash: builtins.bytes
    @property
    def aunts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...
    def __init__(
        self,
        *,
        total: builtins.int = ...,
        index: builtins.int = ...,
        leaf_hash: builtins.bytes = ...,
        aunts: collections.abc.Iterable[builtins.bytes] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aunts", b"aunts", "index", b"index", "leaf_hash", b"leaf_hash", "total", b"total"]) -> None: ...

global___Proof = Proof

@typing_extensions.final
class ValueOp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    PROOF_FIELD_NUMBER: builtins.int
    key: builtins.bytes
    """Encoded in ProofOp.Key."""
    @property
    def proof(self) -> global___Proof:
        """To encode in ProofOp.Data"""
    def __init__(
        self,
        *,
        key: builtins.bytes = ...,
        proof: global___Proof | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["proof", b"proof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "proof", b"proof"]) -> None: ...

global___ValueOp = ValueOp

@typing_extensions.final
class DominoOp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    OUTPUT_FIELD_NUMBER: builtins.int
    key: builtins.str
    input: builtins.str
    output: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        input: builtins.str = ...,
        output: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["input", b"input", "key", b"key", "output", b"output"]) -> None: ...

global___DominoOp = DominoOp

@typing_extensions.final
class ProofOp(google.protobuf.message.Message):
    """ProofOp defines an operation used for calculating Merkle root
    The data could be arbitrary format, providing nessecary data
    for example neighbouring node hash
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    type: builtins.str
    key: builtins.bytes
    data: builtins.bytes
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        key: builtins.bytes = ...,
        data: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "key", b"key", "type", b"type"]) -> None: ...

global___ProofOp = ProofOp

@typing_extensions.final
class ProofOps(google.protobuf.message.Message):
    """ProofOps is Merkle proof defined by the list of ProofOps"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPS_FIELD_NUMBER: builtins.int
    @property
    def ops(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProofOp]: ...
    def __init__(
        self,
        *,
        ops: collections.abc.Iterable[global___ProofOp] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ops", b"ops"]) -> None: ...

global___ProofOps = ProofOps



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.evidence.v1beta1.tx_pb2
import grpc

class MsgStub:
    """Msg defines the evidence Msg service."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    SubmitEvidence: grpc.UnaryUnaryMultiCallable[
        cosmos.evidence.v1beta1.tx_pb2.MsgSubmitEvidence,
        cosmos.evidence.v1beta1.tx_pb2.MsgSubmitEvidenceResponse,
    ]
    """SubmitEvidence submits an arbitrary Evidence of misbehavior such as equivocation or
    counterfactual signing.
    """

class MsgServicer(metaclass=abc.ABCMeta):
    """Msg defines the evidence Msg service."""

    @abc.abstractmethod
    def SubmitEvidence(
        self,
        request: cosmos.evidence.v1beta1.tx_pb2.MsgSubmitEvidence,
        context: grpc.ServicerContext,
    ) -> cosmos.evidence.v1beta1.tx_pb2.MsgSubmitEvidenceResponse:
        """SubmitEvidence submits an arbitrary Evidence of misbehavior such as equivocation or
        counterfactual signing.
        """

def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.query.v1beta1.pagination_pb2
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.incentives.gauge_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ModuleToDistributeCoinsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ModuleToDistributeCoinsRequest = ModuleToDistributeCoinsRequest

@typing_extensions.final
class ModuleToDistributeCoinsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COINS_FIELD_NUMBER: builtins.int
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """Coins that have yet to be distributed"""
    def __init__(
        self,
        *,
        coins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["coins", b"coins"]) -> None: ...

global___ModuleToDistributeCoinsResponse = ModuleToDistributeCoinsResponse

@typing_extensions.final
class GaugeByIDRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.int
    """Gague ID being queried"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___GaugeByIDRequest = GaugeByIDRequest

@typing_extensions.final
class GaugeByIDResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GAUGE_FIELD_NUMBER: builtins.int
    @property
    def gauge(self) -> osmosis.incentives.gauge_pb2.Gauge:
        """Gauge that corresponds to provided gague ID"""
    def __init__(
        self,
        *,
        gauge: osmosis.incentives.gauge_pb2.Gauge | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gauge", b"gauge"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gauge", b"gauge"]) -> None: ...

global___GaugeByIDResponse = GaugeByIDResponse

@typing_extensions.final
class GaugesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """Pagination defines pagination for the request"""
    def __init__(
        self,
        *,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> None: ...

global___GaugesRequest = GaugesRequest

@typing_extensions.final
class GaugesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.incentives.gauge_pb2.Gauge]:
        """Upcoming and active gauges"""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """Pagination defines pagination for the response"""
    def __init__(
        self,
        *,
        data: collections.abc.Iterable[osmosis.incentives.gauge_pb2.Gauge] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "pagination", b"pagination"]) -> None: ...

global___GaugesResponse = GaugesResponse

@typing_extensions.final
class ActiveGaugesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """Pagination defines pagination for the request"""
    def __init__(
        self,
        *,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> None: ...

global___ActiveGaugesRequest = ActiveGaugesRequest

@typing_extensions.final
class ActiveGaugesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.incentives.gauge_pb2.Gauge]:
        """Active gagues only"""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """Pagination defines pagination for the response"""
    def __init__(
        self,
        *,
        data: collections.abc.Iterable[osmosis.incentives.gauge_pb2.Gauge] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "pagination", b"pagination"]) -> None: ...

global___ActiveGaugesResponse = ActiveGaugesResponse

@typing_extensions.final
class ActiveGaugesPerDenomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    denom: builtins.str
    """Desired denom when querying active gagues"""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """Pagination defines pagination for the request"""
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom", b"denom", "pagination", b"pagination"]) -> None: ...

global___ActiveGaugesPerDenomRequest = ActiveGaugesPerDenomRequest

@typing_extensions.final
class ActiveGaugesPerDenomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.incentives.gauge_pb2.Gauge]:
        """Active gagues that match denom in query"""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """Pagination defines pagination for the response"""
    def __init__(
        self,
        *,
        data: collections.abc.Iterable[osmosis.incentives.gauge_pb2.Gauge] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "pagination", b"pagination"]) -> None: ...

global___ActiveGaugesPerDenomResponse = ActiveGaugesPerDenomResponse

@typing_extensions.final
class UpcomingGaugesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """Pagination defines pagination for the request"""
    def __init__(
        self,
        *,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> None: ...

global___UpcomingGaugesRequest = UpcomingGaugesRequest

@typing_extensions.final
class UpcomingGaugesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.incentives.gauge_pb2.Gauge]:
        """Gauges whose distribution is upcoming"""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """Pagination defines pagination for the response"""
    def __init__(
        self,
        *,
        data: collections.abc.Iterable[osmosis.incentives.gauge_pb2.Gauge] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "pagination", b"pagination"]) -> None: ...

global___UpcomingGaugesResponse = UpcomingGaugesResponse

@typing_extensions.final
class UpcomingGaugesPerDenomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    denom: builtins.str
    """Filter for upcoming gagues that match specific denom"""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """Pagination defines pagination for the request"""
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom", b"denom", "pagination", b"pagination"]) -> None: ...

global___UpcomingGaugesPerDenomRequest = UpcomingGaugesPerDenomRequest

@typing_extensions.final
class UpcomingGaugesPerDenomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPCOMING_GAUGES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def upcoming_gauges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.incentives.gauge_pb2.Gauge]:
        """Upcoming gagues that match denom in query"""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """Pagination defines pagination for the response"""
    def __init__(
        self,
        *,
        upcoming_gauges: collections.abc.Iterable[osmosis.incentives.gauge_pb2.Gauge] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination", b"pagination", "upcoming_gauges", b"upcoming_gauges"]) -> None: ...

global___UpcomingGaugesPerDenomResponse = UpcomingGaugesPerDenomResponse

@typing_extensions.final
class RewardsEstRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OWNER_FIELD_NUMBER: builtins.int
    LOCK_IDS_FIELD_NUMBER: builtins.int
    END_EPOCH_FIELD_NUMBER: builtins.int
    owner: builtins.str
    """Address that is being queried for future estimated rewards"""
    @property
    def lock_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """Lock IDs included in future reward estimation"""
    end_epoch: builtins.int
    """Upper time limit of reward estimation
    Lower limit is current epoch
    """
    def __init__(
        self,
        *,
        owner: builtins.str = ...,
        lock_ids: collections.abc.Iterable[builtins.int] | None = ...,
        end_epoch: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_epoch", b"end_epoch", "lock_ids", b"lock_ids", "owner", b"owner"]) -> None: ...

global___RewardsEstRequest = RewardsEstRequest

@typing_extensions.final
class RewardsEstResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COINS_FIELD_NUMBER: builtins.int
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """Estimated coin rewards that will be recieved at provided address
        from specified locks between current time and end epoch
        """
    def __init__(
        self,
        *,
        coins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["coins", b"coins"]) -> None: ...

global___RewardsEstResponse = RewardsEstResponse

@typing_extensions.final
class QueryLockableDurationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___QueryLockableDurationsRequest = QueryLockableDurationsRequest

@typing_extensions.final
class QueryLockableDurationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCKABLE_DURATIONS_FIELD_NUMBER: builtins.int
    @property
    def lockable_durations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.duration_pb2.Duration]:
        """Time durations that users can lock coins for in order to recieve rewards"""
    def __init__(
        self,
        *,
        lockable_durations: collections.abc.Iterable[google.protobuf.duration_pb2.Duration] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lockable_durations", b"lockable_durations"]) -> None: ...

global___QueryLockableDurationsResponse = QueryLockableDurationsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/ibc-rate-limit/v1beta1/params.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+osmosis/ibc-rate-limit/v1beta1/params.proto\x12\x1cosmosis.ibcratelimit.v1beta1\x1a\x14gogoproto/gogo.proto\"?\n\x06Params\x12\x35\n\x10\x63ontract_address\x18\x01 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"contract_address\"B<Z:github.com/osmosis-labs/osmosis/v14/x/ibc-rate-limit/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.ibc_rate_limit.v1beta1.params_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z:github.com/osmosis-labs/osmosis/v14/x/ibc-rate-limit/types'
  _PARAMS.fields_by_name['contract_address']._options = None
  _PARAMS.fields_by_name['contract_address']._serialized_options = b'\362\336\037\027yaml:\"contract_address\"'
  _PARAMS._serialized_start=99
  _PARAMS._serialized_end=162
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MsgJoinPool(google.protobuf.message.Message):
    """===================== MsgJoinPool
    This is really MsgJoinPoolNoSwap
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    SHARE_OUT_AMOUNT_FIELD_NUMBER: builtins.int
    TOKEN_IN_MAXS_FIELD_NUMBER: builtins.int
    sender: builtins.str
    pool_id: builtins.int
    share_out_amount: builtins.str
    @property
    def token_in_maxs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        pool_id: builtins.int = ...,
        share_out_amount: builtins.str = ...,
        token_in_maxs: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id", "sender", b"sender", "share_out_amount", b"share_out_amount", "token_in_maxs", b"token_in_maxs"]) -> None: ...

global___MsgJoinPool = MsgJoinPool

@typing_extensions.final
class MsgJoinPoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHARE_OUT_AMOUNT_FIELD_NUMBER: builtins.int
    TOKEN_IN_FIELD_NUMBER: builtins.int
    share_out_amount: builtins.str
    @property
    def token_in(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        share_out_amount: builtins.str = ...,
        token_in: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["share_out_amount", b"share_out_amount", "token_in", b"token_in"]) -> None: ...

global___MsgJoinPoolResponse = MsgJoinPoolResponse

@typing_extensions.final
class MsgExitPool(google.protobuf.message.Message):
    """===================== MsgExitPool"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    SHARE_IN_AMOUNT_FIELD_NUMBER: builtins.int
    TOKEN_OUT_MINS_FIELD_NUMBER: builtins.int
    sender: builtins.str
    pool_id: builtins.int
    share_in_amount: builtins.str
    @property
    def token_out_mins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        pool_id: builtins.int = ...,
        share_in_amount: builtins.str = ...,
        token_out_mins: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id", "sender", b"sender", "share_in_amount", b"share_in_amount", "token_out_mins", b"token_out_mins"]) -> None: ...

global___MsgExitPool = MsgExitPool

@typing_extensions.final
class MsgExitPoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_OUT_FIELD_NUMBER: builtins.int
    @property
    def token_out(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(
        self,
        *,
        token_out: collections.abc.Iterable[cosmos.base.v1beta1.coin_pb2.Coin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token_out", b"token_out"]) -> None: ...

global___MsgExitPoolResponse = MsgExitPoolResponse

@typing_extensions.final
class SwapAmountInRoute(google.protobuf.message.Message):
    """===================== MsgSwapExactAmountIn"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    TOKEN_OUT_DENOM_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    token_out_denom: builtins.str
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        token_out_denom: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id", "token_out_denom", b"token_out_denom"]) -> None: ...

global___SwapAmountInRoute = SwapAmountInRoute

@typing_extensions.final
class MsgSwapExactAmountIn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    ROUTES_FIELD_NUMBER: builtins.int
    TOKEN_IN_FIELD_NUMBER: builtins.int
    TOKEN_OUT_MIN_AMOUNT_FIELD_NUMBER: builtins.int
    sender: builtins.str
    @property
    def routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SwapAmountInRoute]: ...
    @property
    def token_in(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    token_out_min_amount: builtins.str
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        routes: collections.abc.Iterable[global___SwapAmountInRoute] | None = ...,
        token_in: cosmos.base.v1beta1.coin_pb2.Coin | None = ...,
        token_out_min_amount: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token_in", b"token_in"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["routes", b"routes", "sender", b"sender", "token_in", b"token_in", "token_out_min_amount", b"token_out_min_amount"]) -> None: ...

global___MsgSwapExactAmountIn = MsgSwapExactAmountIn

@typing_extensions.final
class MsgSwapExactAmountInResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_OUT_AMOUNT_FIELD_NUMBER: builtins.int
    token_out_amount: builtins.str
    def __init__(
        self,
        *,
        token_out_amount: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token_out_amount", b"token_out_amount"]) -> None: ...

global___MsgSwapExactAmountInResponse = MsgSwapExactAmountInResponse

@typing_extensions.final
class SwapAmountOutRoute(google.protobuf.message.Message):
    """===================== MsgSwapExactAmountOut"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POOL_ID_FIELD_NUMBER: builtins.int
    TOKEN_IN_DENOM_FIELD_NUMBER: builtins.int
    pool_id: builtins.int
    token_in_denom: builtins.str
    def __init__(
        self,
        *,
        pool_id: builtins.int = ...,
        token_in_denom: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id", "token_in_denom", b"token_in_denom"]) -> None: ...

global___SwapAmountOutRoute = SwapAmountOutRoute

@typing_extensions.final
class MsgSwapExactAmountOut(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    ROUTES_FIELD_NUMBER: builtins.int
    TOKEN_IN_MAX_AMOUNT_FIELD_NUMBER: builtins.int
    TOKEN_OUT_FIELD_NUMBER: builtins.int
    sender: builtins.str
    @property
    def routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SwapAmountOutRoute]: ...
    token_in_max_amount: builtins.str
    @property
    def token_out(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        routes: collections.abc.Iterable[global___SwapAmountOutRoute] | None = ...,
        token_in_max_amount: builtins.str = ...,
        token_out: cosmos.base.v1beta1.coin_pb2.Coin | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token_out", b"token_out"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["routes", b"routes", "sender", b"sender", "token_in_max_amount", b"token_in_max_amount", "token_out", b"token_out"]) -> None: ...

global___MsgSwapExactAmountOut = MsgSwapExactAmountOut

@typing_extensions.final
class MsgSwapExactAmountOutResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_IN_AMOUNT_FIELD_NUMBER: builtins.int
    token_in_amount: builtins.str
    def __init__(
        self,
        *,
        token_in_amount: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token_in_amount", b"token_in_amount"]) -> None: ...

global___MsgSwapExactAmountOutResponse = MsgSwapExactAmountOutResponse

@typing_extensions.final
class MsgJoinSwapExternAmountIn(google.protobuf.message.Message):
    """===================== MsgJoinSwapExternAmountIn
    TODO: Rename to MsgJoinSwapExactAmountIn
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    TOKEN_IN_FIELD_NUMBER: builtins.int
    SHARE_OUT_MIN_AMOUNT_FIELD_NUMBER: builtins.int
    sender: builtins.str
    pool_id: builtins.int
    @property
    def token_in(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    share_out_min_amount: builtins.str
    """repeated cosmos.base.v1beta1.Coin tokensIn = 5 [
      (gogoproto.moretags) = "yaml:\\"tokens_in\\"",
      (gogoproto.nullable) = false
    ];
    """
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        pool_id: builtins.int = ...,
        token_in: cosmos.base.v1beta1.coin_pb2.Coin | None = ...,
        share_out_min_amount: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token_in", b"token_in"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id", "sender", b"sender", "share_out_min_amount", b"share_out_min_amount", "token_in", b"token_in"]) -> None: ...

global___MsgJoinSwapExternAmountIn = MsgJoinSwapExternAmountIn

@typing_extensions.final
class MsgJoinSwapExternAmountInResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHARE_OUT_AMOUNT_FIELD_NUMBER: builtins.int
    share_out_amount: builtins.str
    def __init__(
        self,
        *,
        share_out_amount: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["share_out_amount", b"share_out_amount"]) -> None: ...

global___MsgJoinSwapExternAmountInResponse = MsgJoinSwapExternAmountInResponse

@typing_extensions.final
class MsgJoinSwapShareAmountOut(google.protobuf.message.Message):
    """===================== MsgJoinSwapShareAmountOut"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    TOKEN_IN_DENOM_FIELD_NUMBER: builtins.int
    SHARE_OUT_AMOUNT_FIELD_NUMBER: builtins.int
    TOKEN_IN_MAX_AMOUNT_FIELD_NUMBER: builtins.int
    sender: builtins.str
    pool_id: builtins.int
    token_in_denom: builtins.str
    share_out_amount: builtins.str
    token_in_max_amount: builtins.str
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        pool_id: builtins.int = ...,
        token_in_denom: builtins.str = ...,
        share_out_amount: builtins.str = ...,
        token_in_max_amount: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id", "sender", b"sender", "share_out_amount", b"share_out_amount", "token_in_denom", b"token_in_denom", "token_in_max_amount", b"token_in_max_amount"]) -> None: ...

global___MsgJoinSwapShareAmountOut = MsgJoinSwapShareAmountOut

@typing_extensions.final
class MsgJoinSwapShareAmountOutResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_IN_AMOUNT_FIELD_NUMBER: builtins.int
    token_in_amount: builtins.str
    def __init__(
        self,
        *,
        token_in_amount: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token_in_amount", b"token_in_amount"]) -> None: ...

global___MsgJoinSwapShareAmountOutResponse = MsgJoinSwapShareAmountOutResponse

@typing_extensions.final
class MsgExitSwapShareAmountIn(google.protobuf.message.Message):
    """===================== MsgExitSwapShareAmountIn"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    TOKEN_OUT_DENOM_FIELD_NUMBER: builtins.int
    SHARE_IN_AMOUNT_FIELD_NUMBER: builtins.int
    TOKEN_OUT_MIN_AMOUNT_FIELD_NUMBER: builtins.int
    sender: builtins.str
    pool_id: builtins.int
    token_out_denom: builtins.str
    share_in_amount: builtins.str
    token_out_min_amount: builtins.str
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        pool_id: builtins.int = ...,
        token_out_denom: builtins.str = ...,
        share_in_amount: builtins.str = ...,
        token_out_min_amount: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id", "sender", b"sender", "share_in_amount", b"share_in_amount", "token_out_denom", b"token_out_denom", "token_out_min_amount", b"token_out_min_amount"]) -> None: ...

global___MsgExitSwapShareAmountIn = MsgExitSwapShareAmountIn

@typing_extensions.final
class MsgExitSwapShareAmountInResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_OUT_AMOUNT_FIELD_NUMBER: builtins.int
    token_out_amount: builtins.str
    def __init__(
        self,
        *,
        token_out_amount: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token_out_amount", b"token_out_amount"]) -> None: ...

global___MsgExitSwapShareAmountInResponse = MsgExitSwapShareAmountInResponse

@typing_extensions.final
class MsgExitSwapExternAmountOut(google.protobuf.message.Message):
    """===================== MsgExitSwapExternAmountOut"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SENDER_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    TOKEN_OUT_FIELD_NUMBER: builtins.int
    SHARE_IN_MAX_AMOUNT_FIELD_NUMBER: builtins.int
    sender: builtins.str
    pool_id: builtins.int
    @property
    def token_out(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    share_in_max_amount: builtins.str
    def __init__(
        self,
        *,
        sender: builtins.str = ...,
        pool_id: builtins.int = ...,
        token_out: cosmos.base.v1beta1.coin_pb2.Coin | None = ...,
        share_in_max_amount: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token_out", b"token_out"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pool_id", b"pool_id", "sender", b"sender", "share_in_max_amount", b"share_in_max_amount", "token_out", b"token_out"]) -> None: ...

global___MsgExitSwapExternAmountOut = MsgExitSwapExternAmountOut

@typing_extensions.final
class MsgExitSwapExternAmountOutResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHARE_IN_AMOUNT_FIELD_NUMBER: builtins.int
    share_in_amount: builtins.str
    def __init__(
        self,
        *,
        share_in_amount: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["share_in_amount", b"share_in_amount"]) -> None: ...

global___MsgExitSwapExternAmountOutResponse = MsgExitSwapExternAmountOutResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Equivocation(google.protobuf.message.Message):
    """Equivocation implements the Evidence interface and defines evidence of double
    signing misbehavior.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEIGHT_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    POWER_FIELD_NUMBER: builtins.int
    CONSENSUS_ADDRESS_FIELD_NUMBER: builtins.int
    height: builtins.int
    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    power: builtins.int
    consensus_address: builtins.str
    def __init__(
        self,
        *,
        height: builtins.int = ...,
        time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        power: builtins.int = ...,
        consensus_address: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["time", b"time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["consensus_address", b"consensus_address", "height", b"height", "power", b"power", "time", b"time"]) -> None: ...

global___Equivocation = Equivocation



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/downtime-detector/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from osmosis.downtime_detector.v1beta1 import downtime_duration_pb2 as osmosis_dot_downtime__detector_dot_v1beta1_dot_downtime__duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/osmosis/downtime-detector/v1beta1/genesis.proto\x12 osmosis.downtimedetector.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x39osmosis/downtime-detector/v1beta1/downtime_duration.proto\"\xbe\x01\n\x14GenesisDowntimeEntry\x12Q\n\x08\x64uration\x18\x01 \x01(\x0e\x32*.osmosis.downtimedetector.v1beta1.DowntimeB\x13\xf2\xde\x1f\x0fyaml:\"duration\"\x12S\n\rlast_downtime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB \xc8\xde\x1f\x00\x90\xdf\x1f\x01\xf2\xde\x1f\x14yaml:\"last_downtime\"\"\xb8\x01\n\x0cGenesisState\x12O\n\tdowntimes\x18\x01 \x03(\x0b\x32\x36.osmosis.downtimedetector.v1beta1.GenesisDowntimeEntryB\x04\xc8\xde\x1f\x00\x12W\n\x0flast_block_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\"\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xf2\xde\x1f\x16yaml:\"last_block_time\"B?Z=github.com/osmosis-labs/osmosis/v14/x/downtime-detector/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.downtime_detector.v1beta1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z=github.com/osmosis-labs/osmosis/v14/x/downtime-detector/types'
  _GENESISDOWNTIMEENTRY.fields_by_name['duration']._options = None
  _GENESISDOWNTIMEENTRY.fields_by_name['duration']._serialized_options = b'\362\336\037\017yaml:\"duration\"'
  _GENESISDOWNTIMEENTRY.fields_by_name['last_downtime']._options = None
  _GENESISDOWNTIMEENTRY.fields_by_name['last_downtime']._serialized_options = b'\310\336\037\000\220\337\037\001\362\336\037\024yaml:\"last_downtime\"'
  _GENESISSTATE.fields_by_name['downtimes']._options = None
  _GENESISSTATE.fields_by_name['downtimes']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['last_block_time']._options = None
  _GENESISSTATE.fields_by_name['last_block_time']._serialized_options = b'\310\336\037\000\220\337\037\001\362\336\037\026yaml:\"last_block_time\"'
  _GENESISDOWNTIMEENTRY._serialized_start=286
  _GENESISDOWNTIMEENTRY._serialized_end=476
  _GENESISSTATE._serialized_start=479
  _GENESISSTATE._serialized_end=663
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Since: cosmos-sdk 0.43"""
import builtins
import collections.abc
import cosmos.authz.v1beta1.authz_pb2
import cosmos.base.query.v1beta1.pagination_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QueryGrantsRequest(google.protobuf.message.Message):
    """QueryGrantsRequest is the request type for the Query/Grants RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    MSG_TYPE_URL_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    granter: builtins.str
    grantee: builtins.str
    msg_type_url: builtins.str
    """Optional, msg_type_url, when set, will query only grants matching given msg type."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an pagination for the request."""
    def __init__(
        self,
        *,
        granter: builtins.str = ...,
        grantee: builtins.str = ...,
        msg_type_url: builtins.str = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["grantee", b"grantee", "granter", b"granter", "msg_type_url", b"msg_type_url", "pagination", b"pagination"]) -> None: ...

global___QueryGrantsRequest = QueryGrantsRequest

@typing_extensions.final
class QueryGrantsResponse(google.protobuf.message.Message):
    """QueryGrantsResponse is the response type for the Query/Authorizations RPC method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GRANTS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def grants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.authz.v1beta1.authz_pb2.Grant]:
        """authorizations is a list of grants granted for grantee by granter."""
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines an pagination for the response."""
    def __init__(
        self,
        *,
        grants: collections.abc.Iterable[cosmos.authz.v1beta1.authz_pb2.Grant] | None = ...,
        pagination: cosmos.base.query.v1beta1.pagination_pb2.PageResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination", b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["grants", b"grants", "pagination", b"pagination"]) -> None: ...

global___QueryGrantsResponse = QueryGrantsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class FeeToken(google.protobuf.message.Message):
    """FeeToken is a struct that specifies a coin denom, and pool ID pair.
    This marks the token as eligible for use as a tx fee asset in Osmosis.
    Its price in osmo is derived through looking at the provided pool ID.
    The pool ID must have osmo as one of its assets.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DENOM_FIELD_NUMBER: builtins.int
    POOLID_FIELD_NUMBER: builtins.int
    denom: builtins.str
    poolID: builtins.int
    def __init__(
        self,
        *,
        denom: builtins.str = ...,
        poolID: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom", b"denom", "poolID", b"poolID"]) -> None: ...

global___FeeToken = FeeToken
